mod cli_exact;
mod cli_inst_interactive;
mod cli_misc;
mod cli_paths;
mod cli_rustup;
mod cli_self_upd;
mod cli_ui;
mod cli_v1;
mod cli_v2;
mod dist_install;
